'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _dotenvFlow = require('dotenv-flow');

var _dotenvFlow2 = _interopRequireDefault(_dotenvFlow);

var _webpack = require('webpack');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * The `dotenv-flow-webpack` plugin.
 */
var DotenvFlow =
/**
 * @constructor
 * @param {Object} [options] - Options for parsing `.env*` files
 * @param {String} [options.environment='development'] - The value for `process.env.NODE_ENV` if it's not set
 * @param {String} [options.path=process.cwd()] - The path to a directory where `.env*` files are located
 * @param {String} [options.encoding='utf8'] - Encoding of `.env*` files
 * @param {Boolean} [options.systemvars=false] - If true, load system environment variables.
 * @param {Boolean} [options.silent=false] - If true, suppress warnings, if false, display warnings.
 * @returns {webpack.DefinePlugin}
 */
function DotenvFlow() {
  var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
      _ref$environment = _ref.environment,
      environment = _ref$environment === undefined ? 'development' : _ref$environment,
      _ref$path = _ref.path,
      path = _ref$path === undefined ? process.cwd() : _ref$path,
      _ref$encoding = _ref.encoding,
      encoding = _ref$encoding === undefined ? 'utf8' : _ref$encoding,
      _ref$systemvars = _ref.systemvars,
      systemvars = _ref$systemvars === undefined ? false : _ref$systemvars,
      _ref$silent = _ref.silent,
      silent = _ref$silent === undefined ? false : _ref$silent;

  _classCallCheck(this, DotenvFlow);

  var vars = {};
  if (systemvars) {
    Object.keys(process.env).map(function (key) {
      vars[key] = process.env[key];
    });
  }

  var options = {
    default_node_env: environment,
    cwd: path,
    encoding: encoding
  };

  var _dotenv$config = _dotenvFlow2.default.config(options),
      _dotenv$config$parsed = _dotenv$config.parsed,
      parsed = _dotenv$config$parsed === undefined ? undefined : _dotenv$config$parsed,
      _dotenv$config$error = _dotenv$config.error,
      error = _dotenv$config$error === undefined ? undefined : _dotenv$config$error;

  if (error) {
    silent || console.warn(error.message);
  } else {
    Object.keys(parsed).forEach(function (key) {
      vars[key] = parsed[key];
    });
  }

  var formatData = Object.keys(vars).reduce(function (obj, key) {
    obj['process.env.' + key] = JSON.stringify(vars[key]);
    return obj;
  }, {});

  return new _webpack.DefinePlugin(formatData);
};

exports.default = DotenvFlow;